@@ -10,26 +10,23 @@
 #ifndef AKONADICONSOLE_JOBTRACKER_H
 #define AKONADICONSOLE_JOBTRACKER_H
 
-#include <QObject>
+#include "libakonadiconsole_export.h"
 #include <QDateTime>
 #include <QList>
+#include <QObject>
 #include <QPair>
-#include "libakonadiconsole_export.h"
 class JobInfo
 {
 public:
-    JobInfo() : parent(-1)
+    JobInfo()
+        : parent(-1)
         , state(Initial)
     {
     }
 
     bool operator==(const JobInfo &other) const
     {
-        return name == other.name
-               && parent == other.parent
-               && type == other.type
-               && timestamp == other.timestamp
-               && state == other.state;
+        return name == other.name && parent == other.parent && type == other.type && timestamp == other.timestamp && state == other.state;
     }
 
     QString name;
@@ -38,12 +35,7 @@ public:
     QDateTime timestamp;
     QDateTime startedTimestamp;
     QDateTime endedTimestamp;
-    enum JobState {
-        Initial = 0,
-        Running,
-        Ended,
-        Failed
-    };
+    enum JobState { Initial = 0, Running, Ended, Failed };
     JobState state;
     QString error;
     QString debugString;
@@ -88,21 +80,21 @@ public:
 
 Q_SIGNALS:
     /** Emitted when a job (or session) is about to be added to the tracker.
-      * @param pos the position of the job or session relative to the parent
-      * @param parentId the id of that parent.
-      * This makes it easy for the model to find and update the right
-      * part of the model, for efficiency.
-      */
+     * @param pos the position of the job or session relative to the parent
+     * @param parentId the id of that parent.
+     * This makes it easy for the model to find and update the right
+     * part of the model, for efficiency.
+     */
     void aboutToAdd(int pos, int parentId);
     void added();
 
     /** Emitted when jobs (or sessiona) have been updated in the tracker.
-    * The format is a list of pairs consisting of the position of the
-    * job or session relative to the parent and the id of that parent.
-    * This makes it easy for the model to find and update the right
-    * part of the model, for efficiency.
-    */
-    void updated(const QList< QPair<int, int> > &updates);
+     * The format is a list of pairs consisting of the position of the
+     * job or session relative to the parent and the id of that parent.
+     * This makes it easy for the model to find and update the right
+     * part of the model, for efficiency.
+     */
+    void updated(const QList<QPair<int, int>> &updates);
 
 public Q_SLOTS:
     Q_SCRIPTABLE void jobCreated(const QString &session, const QString &jobName, const QString &parentJob, const QString &jobType, const QString &debugString);
